==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiWebEngineCore/QWebEngineUrlRequestInterceptor_shell.h <==
#ifndef QWEBENGINEURLREQUESTINTERCEPTOR_SHELL_H
#define QWEBENGINEURLREQUESTINTERCEPTOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWebEngineCore/qwebengineurlrequestinfo.h>
#include <QtJambi/RegistryAPI>


class QWebEngineUrlRequestInterceptor_shell : public QWebEngineUrlRequestInterceptor, public QtJambiShellInterface
{
public:
    QWebEngineUrlRequestInterceptor_shell(QObject* p0 = nullptr);
    ~QWebEngineUrlRequestInterceptor_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void interceptRequest(QWebEngineUrlRequestInfo& info0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebEngineUrlRequestInterceptor_access : public QWebEngineUrlRequestInterceptor
{
    void __qt_interceptRequest_ref_QWebEngineUrlRequestInfo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID info0);
};

#endif // QWEBENGINEURLREQUESTINTERCEPTOR_SHELL_H

==> qtjambi-webenginecore-debuginfo-windows-x64-6.7.1.jar: sources/QtJambiWebEngineCore/QWebEngineUrlRequestInterceptor_shell.h <==
#ifndef QWEBENGINEURLREQUESTINTERCEPTOR_SHELL_H
#define QWEBENGINEURLREQUESTINTERCEPTOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtWebEngineCore/qwebengineurlrequestinfo.h>
#include <QtJambi/RegistryAPI>


class QWebEngineUrlRequestInterceptor_shell : public QWebEngineUrlRequestInterceptor, public QtJambiShellInterface
{
public:
    QWebEngineUrlRequestInterceptor_shell(QObject* p0 = nullptr);
    ~QWebEngineUrlRequestInterceptor_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QWebEngineUrlRequestInterceptor_mshell;
    friend class QWebEngineUrlRequestInterceptor_oshell;
};


class QWebEngineUrlRequestInterceptor_mshell : public QWebEngineUrlRequestInterceptor_shell
{
public:
    using QWebEngineUrlRequestInterceptor_shell::QWebEngineUrlRequestInterceptor_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QWebEngineUrlRequestInterceptor_oshell : public QWebEngineUrlRequestInterceptor_mshell
{
public:
    using QWebEngineUrlRequestInterceptor_mshell::QWebEngineUrlRequestInterceptor_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void interceptRequest(QWebEngineUrlRequestInfo& info0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebEngineUrlRequestInterceptor_access : public QWebEngineUrlRequestInterceptor
{
    void __qt_interceptRequest_ref_QWebEngineUrlRequestInfo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID info0);
};

#endif // QWEBENGINEURLREQUESTINTERCEPTOR_SHELL_H
